/*****************************************************************************/
/**                                                                         **/
/** (C) Copyright 2003 - Analog Devices, Inc.  All rights reserved.         **/
/**                                                                         **/
/*****************************************************************************/
/*****************************************************************************/

/*****************************************************************************/
/*               ADI DSP Division, EMP, Munich					             */
/*****************************************************************************/
/*
 *
 * FILE NAME	: GPIO_Setup_BF5xx.c	
 *
 * DATE         : $Date: 2006/12/01 07:44:35 $
 *
 * AUTHOR(S)    : $Author: ANALOG\tlorenz $
 *
 * REVISION NO. : $Revision: 2.0 $
 *
 * DESCRIPTION  :  ADV reset and enable control
 *
 *
 * SOFTWARE		: VisualDSP++4.5 (November Update)
 *
 * HARDWARE		: ADSP-BF561 EZ-KIT REV 2.0 BF561 Chip Rev 0.5
 *				: ADSP-BF533 EZ-KIT REV 1.7 BF533 Chip Rev 0.4
 *
 *
 *****************************************************************************/

/*****************************************************************************************/
// Prototypes
/*****************************************************************************************/
void Init_EBIU(void);
void Init_Flash(void);
void Init_ADV7183(void);
void Init_ADV7171(void);

/*****************************************************************************************/
// Program
/*****************************************************************************************/
#include <GPIO_Setup_BF5xx.h>

#ifdef __ADSPBF561__

void Reset_ADV7183(void ){
	long delay_time;

	// configure OE and RESET flags as output
	*pFIO_DIR |= (1 << ADV7183_OE_bit) | (1 << ADV7183_RESET_bit);

	// disable outputs
	*pFIO_FLAG_S = (1 << ADV7183_OE_bit);	// set bit to disable ADV7183 outputs

	// generate reset pulse
	*pFIO_FLAG_C = (1 << ADV7183_RESET_bit);	// clear bit to reset ADV7183 

	*pFIO_FLAG_S = (1 << ADV7183_RESET_bit);	// set bit to re-enable ADV7183 

	for (delay_time = 0; delay_time < ADV7183_Reset_Delay; delay_time++)
			asm("nop;");

	// now enable outputs
	*pFIO_FLAG_C = (1 << ADV7183_OE_bit);	// clear bit to enable ADV7183 outputs

	for (delay_time = 0; delay_time < ADV7183_Lock; delay_time++)
			asm("nop;");
	
}

void Reset_ADV7179(void ){
	long delay_time;


	// configure RESET flag as output
	*pFIO_DIR |= (1 << ADV7179_RESET_bit);

	// generate reset pulse
	*pFIO_FLAG_C = (1 << ADV7179_RESET_bit);	// clear bit to reset ADV7179 

	*pFIO_FLAG_S = (1 << ADV7179_RESET_bit);	// set bit to re-enable ADV7179 

	for (delay_time = 0; delay_time < ADV7179_Reset_Delay; delay_time++)
		asm("nop;");

}

#endif


#ifdef __ADSPBF533__

void Reset_ADV7183(void ){
	Init_EBIU();
	Init_Flash();
	Init_ADV7183();
}

void Reset_ADV7179(void){
	Init_EBIU();
	Init_Flash();
	Init_ADV7171();
}

//Setup of the async interface
void Init_EBIU(void){
	
	*pEBIU_AMBCTL0	= 0x7bb07bb0;	// <--|Write access time = 7 cycles, read access time = 11 cycles, no ARDY
	*pEBIU_AMBCTL1	= 0x7bb07bb0;	//    |Hold time = 2 cycles, setup time = 3 cycles, transition time = 4 cycles
	*pEBIU_AMGCTL	= 0x000F;		//	  |Enable all memory banks

}//end Init_EBIU


//To use the GPIOs of the flash it must be initialized
void Init_Flash(void){
	*pFlashA_PortA_Out = 0x0;		// clear data registers
	*pFlashA_PortA_Dir = 0xFFFF;	// set dir=output
}//end Init_Flash



//The GPIOs of the flash are linked to the ADV7183 reset pin
void Init_ADV7183(void){
	unsigned char tempReg;
	
	//De-assert the ADV7183 reset
	tempReg = *pFlashA_PortA_Out;
	*pFlashA_PortA_Out = tempReg | RST_7183;

}//end Init_ADV

//The GPIOs of the flash are linked to the ADV7171 reset pin
void Init_ADV7171(void){
	unsigned char tempReg;
	
	//De-assert the ADV7171 reset
	tempReg = *pFlashA_PortA_Out;
	*pFlashA_PortA_Out = tempReg | RST_7171;

}//end Init_ADV

#endif
